//-------------------------------------------------------------------------------
// ColorRadioWaves.class - A Java applet that draws radio waves emanating
//                         from its centre. The waves may be different
//                         colours.
//-------------------------------------------------------------------------------
// Copyright (C) 1997 by James MacKay
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//
// The author can be contacted via e-mail at: jmackay@sentex.net
//--------------------------------------------------------------------------
import java.awt.Graphics;
import java.awt.Color;
import java.util.Vector;

/**
* Draws repeating series of radio waves emitted from its centre. The colour
* of each wave in a series can be specified by the user.
* Also see ColorRadioWaves`
* <a href="ColorRadioWaves-params.html">applet parameters
* documentation</a>.
* @version 1.1
* @author James MacKay (<a href="mailto:jmackay@sentex.net">jmackay@sentex.net</a>)
*/
public class ColorRadioWaves extends RadioWaves
   {
   private Vector color;
   private int currColorIndex;

   public void init()
      {
      super.init();

      int colorCount = getIntParameter("colorCount", 1);
      color = new Vector(colorCount);

      // the first colour defaults to black; the remaining colours default
      // to the previous colour:
      Color temp = getColorParameter("color0", Color.black);
      color.addElement(temp);
      for (int i = 1; i < colorCount; i++)
         {
         temp = getColorParameter("color" + i,
                                  (Color)color.elementAt(i - 1));
         color.addElement(temp);
         }
      }

   /**
   * Initializes the wave colour(s) before a series of waves is emitted.
   * @param g the Graphics object on which the series of waves will be drawn
   */
   protected void initWaveColors(Graphics g)
      {
      currColorIndex = 0;
      }

   /**
   * Sets the colour of the next wave to be drawn.
   * @param g the Graphics object on which the wave will be drawn
   */
   protected void setNextWaveColor(Graphics g)
      {
      g.setColor((Color)color.elementAt(currColorIndex));

      if (++currColorIndex >= color.size())
         currColorIndex = 0;
      }

   /**
   * Returns version, author and copyright information about the
   * ColorRadioWaves applet.
   */
   public String getAppletInfo()
      {
      return "MulticoloredRadioWaves version 1.1, " +
             "Copyright (C) 1997 by James MacKay";
      }

   /**
   * Describes each of ColorRadioWaves` applet parameters.
   */
   public String[][] getParameterInfo()
      {
      String[][] superInfo = super.getParameterInfo();
      String[][] thisInfo =
         {
         { "colorCount", "count",
              "number of wave colours" },
         { "color0", "hexadecimal colour value",
              "the colour of the first wave in each series " +
              "(defaults to black)" },
         { "colorn", "hexadecimal colour value",
              "(for n=1,2,...,(colorCount-1)) the colour of the " +
              "(n+1)th wave in each series " +
              "(defaults to the colour of the n`th wave)"}
         };  // String[][] thisInfo;

      int infoSize = thisInfo.length + superInfo.length;
      String[][] info = new String[infoSize][3];
      for (int i = 0; i < superInfo.length; i++)
         for (int j = 0; j < 3; j++)
            info[i][j] = superInfo[i][j];
      for (int i = superInfo.length; i < infoSize; i++)
         for (int j = 0; j < 3; j++)
            info[i][j] = thisInfo[i - superInfo.length][j];

      return info;
      }
   }  // class ColorRadioWaves

